@@ -1,5 +1,5 @@
 import redis.asyncio as aioredis
 
-from core.config import config
+from vulcan.core.config import config
 
 redis = aioredis.from_url(url=f"redis://{config.REDIS_HOST}")
